# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-18 06:22
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0043_auto_20191018_1404'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userlevel',
            options={'ordering': ['number'], 'permissions': (('view_level_list', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u5347\u7ea7\u5217\u8868'),)},
        ),
        migrations.RemoveField(
            model_name='userlevel',
            name='level',
        ),
        migrations.AddField(
            model_name='userlevel',
            name='number',
            field=models.IntegerField(default=0, verbose_name='\u987a\u5e8f'),
        ),
        migrations.AlterField(
            model_name='userleveluprecord',
            name='level',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='bee_django_user_level', to='bee_django_user.UserLevel', verbose_name='\u987a\u5e8f'),
        ),
    ]
