# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-21 06:19
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0048_auto_20191115_1607'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userleveluprecord',
            name='level',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='bee_django_user_level', to='bee_django_user.UserLevel', verbose_name='\u5347\u7ea7\u6807\u9898'),
        ),
    ]
