# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-15 08:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0047_userclassremoverecord'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userclass',
            name='name',
            field=models.CharField(help_text='\u4e0d\u80fd\u548c\u5df2\u6709\u73ed\u7ea7\u91cd\u540d', max_length=180, unique=True, verbose_name='\u73ed\u7ea7\u540d\u79f0'),
        ),
    ]
