# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-16 06:51
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0008_alter_user_username_max_length'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_user', '0037_auto_20191012_1354'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserLevel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u6807\u9898')),
                ('level', models.IntegerField(default=0, verbose_name='\u7ea7\u522b')),
                ('detail', models.TextField(blank=True, null=True, verbose_name='\u8be6\u60c5')),
                ('after_group', models.ManyToManyField(help_text='\uff08\u4e0d\u53ef\u591a\u9009\uff09', related_name='user_after_group', to='auth.Group', verbose_name='\u5347\u7ea7\u540e\u7684\u7528\u6237\u7ec4')),
                ('before_group', models.ManyToManyField(help_text='\uff08\u53ef\u591a\u9009\uff09', related_name='user_before_group', to='auth.Group', verbose_name='\u53ef\u5347\u7ea7\u7528\u6237\u7ec4')),
            ],
            options={
                'ordering': ['level'],
                'db_table': 'bee_django_user_level',
                'permissions': (('view_level_list', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u5347\u7ea7\u5217\u8868'),),
            },
        ),
        migrations.CreateModel(
            name='UserLevelUpRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.IntegerField(blank=True, choices=[(-1, '\u672a\u7533\u8bf7'), (-2, '\u5df2\u7533\u8bf7'), (1, '\u901a\u8fc7'), (2, '\u672a\u901a\u8fc7'), (3, '\u5173\u95ed')], default=-1, null=True, verbose_name='\u72b6\u6001')),
                ('detail', models.TextField(blank=True, null=True, verbose_name='\u8be6\u60c5')),
                ('info', models.TextField(blank=True, null=True, verbose_name='\u5176\u4ed6')),
                ('level', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='bee_django_user_level', to='bee_django_user.UserLevel', verbose_name='\u7ea7\u522b')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='bee_django_level_up_user', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_user_level_up_record',
            },
        ),
    ]
