# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-15 06:52
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_user', '0046_auto_20191114_1630'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserClassRemoveRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('created_by', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='created_by', to=settings.AUTH_USER_MODEL, verbose_name='\u64cd\u4f5c\u4eba')),
                ('new_class', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='new_class', to='bee_django_user.UserClass', verbose_name='\u65b0\u73ed\u7ea7')),
                ('old_class', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='old_class', to='bee_django_user.UserClass', verbose_name='\u539f\u73ed\u7ea7')),
                ('student', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='student', to=settings.AUTH_USER_MODEL, verbose_name='\u5b66\u751f')),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_user_class_remove_record',
            },
        ),
    ]
