# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-16 07:32
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0008_alter_user_username_max_length'),
        ('bee_django_user', '0038_userlevel_userleveluprecord'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='userlevel',
            name='after_group',
        ),
        migrations.AddField(
            model_name='userlevel',
            name='after_group',
            field=models.ForeignKey(help_text='\uff08\u4e0d\u53ef\u591a\u9009\uff09', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='user_after_group', to='auth.Group', verbose_name='\u5347\u7ea7\u540e\u7684\u7528\u6237\u7ec4'),
        ),
    ]
