# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-22 05:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0050_userleveluprecord_supplement'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userleveluprecord',
            name='status',
            field=models.IntegerField(blank=True, choices=[(-1, '\u672a\u7533\u8bf7'), (-2, '\u5df2\u7533\u8bf7'), (1, '\u901a\u8fc7'), (2, '\u672a\u901a\u8fc7'), (3, '\u5173\u95ed'), (4, '\u5df2\u63d0\u4ea4\u8865\u5145\u8d44\u6599')], default=-1, null=True, verbose_name='\u72b6\u6001'),
        ),
    ]
