# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-21 08:10
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0049_auto_20191121_1419'),
    ]

    operations = [
        migrations.AddField(
            model_name='userleveluprecord',
            name='supplement',
            field=models.TextField(blank=True, null=True, verbose_name='\u8865\u5145\u8d44\u6599'),
        ),
    ]
