# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-18 05:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0039_auto_20191016_1532'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userleveluprecord',
            options={'ordering': ['-created_at'], 'permissions': (('view_all_level_up_records', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u5347\u7ea7\u5217\u8868'),)},
        ),
        migrations.RemoveField(
            model_name='userleveluprecord',
            name='detail',
        ),
        migrations.AddField(
            model_name='userleveluprecord',
            name='application',
            field=models.TextField(blank=True, null=True, verbose_name='\u7533\u8bf7\u5185\u5bb9'),
        ),
        migrations.AddField(
            model_name='userleveluprecord',
            name='histroy',
            field=models.TextField(blank=True, null=True, verbose_name='\u5386\u53f2\u8bb0\u5f55'),
        ),
        migrations.AddField(
            model_name='userleveluprecord',
            name='req',
            field=models.TextField(blank=True, null=True, verbose_name='\u7533\u8bf7\u8981\u6c42'),
        ),
    ]
