# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-10 07:18
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0035_auto_20190923_1715'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='live_mins',
            field=models.IntegerField(default=0, verbose_name='\u76f4\u64ad\u65f6\u957f'),
        ),
    ]
