# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-18 06:04
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0042_auto_20191018_1400'),
    ]

    operations = [
        migrations.RenameField(
            model_name='userleveluprecord',
            old_name='histroy',
            new_name='history',
        ),
    ]
