# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-18 05:59
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0040_auto_20191018_1358'),
    ]

    operations = [
        migrations.RenameField(
            model_name='userlevel',
            old_name='detail',
            new_name='req',
        ),
        migrations.RemoveField(
            model_name='userleveluprecord',
            name='req',
        ),
    ]
