# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-18 06:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_user', '0041_auto_20191018_1359'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userlevel',
            name='req',
            field=models.TextField(blank=True, null=True, verbose_name='\u7533\u8bf7\u8981\u6c42'),
        ),
    ]
